@@ -37,9 +37,18 @@ class InstanceManager(ManagedAuthentication):
         self.image_registry_credentials = image_registry_credentials
 
     def provision(
-        self, name, memory: float = 1, cpu: float = 1, ports=None,
-            command=['/bin/sh' ,'-c', f'apt-get update && apt-get install python3 python3-pip python3-dev -y && python3 -m pip install acido=={__version__} && sleep infinity'], image = 'ubuntu:20.04',
-            env_vars: dict = {}
+        self, 
+        name, 
+        memory: float = 1, 
+        cpu: float = 1, 
+        ports=None,
+        command=[
+            '/bin/sh',
+            '-c', 
+            f'apt-get update && apt-get install python3 python3-pip python3-dev -y && python3 -m pip install acido=={__version__} && sleep infinity'
+        ], 
+        image = 'ubuntu:20.04',
+        env_vars: dict = {}
     ):
         env = {}
 
@@ -65,16 +74,6 @@ class InstanceManager(ManagedAuthentication):
         )
         return instance
 
-    def set_variable(self, key: str, value: str):
-        self.env_vars[key] = EnvironmentVariable(
-            name=key,
-            value=value
-        )
-
-    def set_variables(self, d: dict):
-        for k, v in d.items():
-            self.set_variable(k, v)
-
     def deploy(
         self, name, tags: dict = {}, location="westeurope",
         ip_address=None, os_type=OperatingSystemTypes.linux,
@@ -108,7 +107,15 @@ class InstanceManager(ManagedAuthentication):
         deploy_instances = []
 
         for i_num in range(1, instance_number + 1):
-            deploy_instances.append(self.provision(f'{name}-{i_num:02d}', memory=float(max_ram), cpu=float(max_cpu), env_vars=env_vars))
+            env_vars['INSTANCE_NAME'] = f'{name}-{i_num:02d}'
+            deploy_instances.append(
+                self.provision(
+                    f'{name}-{i_num:02d}', 
+                    memory=float(max_ram), 
+                    cpu=float(max_cpu), 
+                    env_vars=env_vars
+                    )
+                )
 
         try:
             cg = ContainerGroup(
