@@ -166,14 +166,15 @@ class Acido(object):
             self.rows, self.cols = os.popen('stty size', 'r').read().split()
         except:
             self.rows, self.cols = 55, 160
-
+        
         try:
             self._load_config()
         except FileNotFoundError:
             self.setup()
         
-        az_identity_list = subprocess.check_output(f'az identity create --resource-group {self.rg} --name acido', shell=True)
+
         try:
+            az_identity_list = subprocess.check_output(f'az identity create --resource-group {self.rg} --name acido', shell=True)
             az_identity_list = json.loads(az_identity_list)
             self.user_assigned = az_identity_list
         except Exception as e:
@@ -369,15 +370,33 @@ class Acido(object):
             instance_num_groups = list(chunks(range(1, instance_num + 1), 10))
             for cg_n, ins_num in enumerate(instance_num_groups):
                 group_name = f'{fleet_name}-{cg_n+1:02d}'
+                env_vars = {
+                    'RG': self.rg,
+                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
+                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+                }
                 if group_name not in response.keys():
                     response[group_name] = []
                 last_instance = len(ins_num)
                 response[group_name] = self.instance_manager.deploy(
                                             name=group_name, 
-                                            instance_number=last_instance
+                                            instance_number=last_instance,
+                                            env_vars=env_vars
                                         )
         else:
-            response[fleet_name] = self.instance_manager.deploy(command=command, name=fleet_name, instance_number=instance_num, env_vars={'INSTANCE_NAME': f'{fleet_name}-{instance_num:02d}'})
+            env_vars = {
+                    'RG': self.rg,
+                    'IMAGE_REGISTRY_SERVER': self.image_registry_server,
+                    'IMAGE_REGISTRY_USERNAME': self.image_registry_username,
+                    'IMAGE_REGISTRY_PASSWORD': self.image_registry_password
+                }
+            response[fleet_name] = self.instance_manager.deploy(
+                command=command, 
+                name=fleet_name, 
+                instance_number=instance_num, 
+                env_vars=env_vars
+            )
         
         if not interactive:
             return response
@@ -395,11 +414,11 @@ class Acido(object):
             return
 
     def setup(self):
-        rg = input(info('Please provide a Resource Group Name to deploy the ACIs: '))
+        rg = os.getenv('RG') if os.getenv('RG', None) else input(info('Please provide a Resource Group Name to deploy the ACIs: '))
         self.rg = rg
-        image_registry_server = input(info('Image Registry Server: '))
-        image_registry_username = input(info('Image Registry Username: '))
-        image_registry_password = input(info('Image Registry Password: '))
+        image_registry_server = os.getenv('IMAGE_REGISTRY_SERVER') if os.getenv('RG', None) else input(info('Image Registry Server: '))
+        image_registry_username = os.getenv('IMAGE_REGISTRY_USERNAME') if os.getenv('IMAGE_REGISTRY_USERNAME', None) else input(info('Image Registry Username: '))
+        image_registry_password = os.getenv('IMAGE_REGISTRY_PASSWORD') if os.getenv('IMAGE_REGISTRY_PASSWORD', None) else input(info('Image Registry Password: '))
         self.selected_instances = []
         self.image_registry_server = image_registry_server
         self.image_registry_username = image_registry_username
